collect_code_blocks

Function collect_code_blocks 

pub fn collect_code_blocks(
    tree: &SyntaxNode,
    _input: &str,
    config: &Config,
) -> Vec<ExternalCodeBlock>
Collect all code blocks and their info strings from the syntax tree. Collect all code blocks from the syntax tree for external formatting. Returns a flat list of (language, content) pairs.